==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/notifier/translations/notifier_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="29"/>
        <source>Notifier Plugin</source>
        <translation>Greffon de notification</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>À propos du greffon de notification</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Greffon de notification pour Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="116"/>
        <source>Volume:</source>
        <translation>Volume&#xa0;:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Configuration du greffon de notification</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notification de bureau</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Font:</source>
        <translation>Police&#xa0;:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Transparency:</source>
        <translation>Transparence : </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="251"/>
        <source>Edit template</source>
        <translation>Éditer le patron</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Taille de la couverture : </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Notification de changement de volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Délai (ms)&#xa0;:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Notification de reprise de lecture</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Notification de changement de morceau</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="375"/>
        <source>Disable notifications when another application is in the Full Screen Mode</source>
        <translation>Désactiver les notifications quand une autre application est en mode plein écran</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Disable for full screen windows</source>
        <translation>Désactiver pour les fenêtres en plein écran</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="388"/>
        <source>Psi Notification</source>
        <translation>Notification Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="400"/>
        <source>Enable Psi notification</source>
        <translation>Activer les notifications Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Notification Template</source>
        <translation>Patron de notification</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/General/notifier/translations/notifier_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="29"/>
        <source>Notifier Plugin</source>
        <translation>Greffon de notification</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>À propos du greffon de notification</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Greffon de notification pour Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>NotifierSettingsDialog</name>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Configuration du greffon de notification</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notification de bureau</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="51"/>
        <source>Font:</source>
        <translation>Police&#xa0;:</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="78"/>
        <location filename="../notifiersettingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="85"/>
        <source>Transparency:</source>
        <translation>Transparence : </translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="229"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="251"/>
        <source>Edit template</source>
        <translation>Éditer le patron</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Taille de la couverture : </translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Notification de changement de volume</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Délai (ms)&#xa0;:</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Notification de reprise de lecture</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Notification de changement de morceau</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="375"/>
        <source>Disable notifications when another application is in the Full Screen Mode</source>
        <translation>Désactiver les notifications quand une autre application est en mode plein écran</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="378"/>
        <source>Disable for full screen windows</source>
        <translation>Désactiver pour les fenêtres en plein écran</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="388"/>
        <source>Psi Notification</source>
        <translation>Notification Psi</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="400"/>
        <source>Enable Psi notification</source>
        <translation>Activer les notifications Psi</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.cpp" line="115"/>
        <source>Notification Template</source>
        <translation>Patron de notification</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="115"/>
        <source>Volume:</source>
        <translation>Volume&#xa0;:</translation>
    </message>
</context>
</TS>
